==> igloo_0_1_2.zip: igloo_0_1_2/igloo/language/1/barnraiser_01/msg_view.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of Igloo
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'common.lang.php');


//HEADER
$lang['hdr_message_subject'] = 					"subject";
$lang['hdr_message_sent'] = 					"sent";
$lang['txt_message_list'] = 					"message list";


//ERRORS
$lang['err_no_friends'] = 						"Sorry, you have no friends to send messages to.";


//SUBMIT BUTTONS
$lang['sub_preview'] = 							"preview";
$lang['sub_edit'] = 							"edit";


//BODY TEXT
$lang['txt_from'] = 							"from";
$lang['txt_message_size'] = 					"message size";
$lang['txt_reply_help'] = 						"Reply to this message";
$lang['txt_message_type1'] = 					"Click HERE to add this person now!";


//section titles
$lang['hdr_menu'] = 						"menu";
$lang['hdr_action'] = 						"do";
$lang['hdr_messages'] = 					"messages";


//HEADER
$lang['hdr_in_box'] = 							"inbox";
$lang['hdr_message'] = 							"message";
$lang['hdr_message_statistics'] = 				"message statistics";
$lang['hdr_out_box'] = 							"outbox";
$lang['hdr_save_box'] = 						"savebox";


//ERRORS
$lang['err_no_messages'] = 						"Sorry, you have no messages.";
$lang['err_no_file'] = 							"Sorry, file available.";


//SUBMIT BUTTONS
$lang['sub_send'] = 							"send";
$lang['sub_select_all'] = 						"select all";


// OPTIONS
$lang['txt_option_reply'] = 					"reply";
$lang['txt_option_read'] = 						"mark as read";
$lang['txt_option_unread'] = 					"mark as unread";
$lang['txt_option_move'] = 						"move to savebox";
$lang['txt_option_delete'] = 					"delete";
$lang['txt_option_inbox'] = 					"inbox";
$lang['txt_option_outbox'] = 					"outbox";
$lang['txt_option_savebox'] = 					"savebox";
$lang['txt_option_compose'] = 					"compose";


//BODY TEXT
$lang['txt_box'] = 								"box";
$lang['txt_box_in'] = 							"in";
$lang['txt_box_out'] = 							"out";
$lang['txt_box_save'] = 						"save";
$lang['txt_delete_help'] = 						"To delete messages check the box next to the item(s) you want to delete and then press 'delete' button.";
$lang['txt_mess-status_help'] = 				"To mark your messages as read/unread check the box next to the item(s) and then press the 'read'/'unread' button.";
$lang['txt_messages'] = 						"messages";
$lang['txt_move_to_save_help'] = 				"To move messages from you current box to your save box check the box next to the item(s) and then press the 'save' button.";
$lang['txt_opened'] = 							"opened";
$lang['txt_size'] = 							"size";
$lang['txt_totals'] = 							"totals";
$lang['txt_unopened'] = 						"unopened";
$lang['txt_used'] = 							"used";
$lang['txt_mess_status'] = 						"message status";
$lang['txt_mess_delete'] = 						"delete messages";
$lang['txt_mess_save'] = 						"save messages";
$lang['txt_mess_reply'] = 						"reply";

?>

==> igloo_0_1_4.zip: igloo_0_1_4/igloo/language/1/barnraiser_01/msg_view.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of Igloo
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'common.lang.php');


//HEADER
$lang['hdr_message_subject'] = 					"subject";
$lang['hdr_message_sent'] = 					"sent";
$lang['txt_message_list'] = 					"message list";


//ERRORS
$lang['err_no_friends'] = 						"Sorry, you have no friends to send messages to.";


//SUBMIT BUTTONS
$lang['sub_preview'] = 							"preview";
$lang['sub_edit'] = 							"edit";


//BODY TEXT
$lang['txt_from'] = 							"from";
$lang['txt_message_size'] = 					"message size";
$lang['txt_reply_help'] = 						"Reply to this message";
$lang['txt_message_type1'] = 					"Click HERE to add this person now!";


//section titles
$lang['hdr_menu'] = 						"menu";
$lang['hdr_action'] = 						"do";
$lang['hdr_messages'] = 					"messages";


//HEADER
$lang['hdr_in_box'] = 							"inbox";
$lang['hdr_message'] = 							"message";
$lang['hdr_message_statistics'] = 				"message statistics";
$lang['hdr_out_box'] = 							"outbox";
$lang['hdr_save_box'] = 						"savebox";


//ERRORS
$lang['err_no_messages'] = 						"Sorry, you have no messages.";
$lang['err_no_file'] = 							"Sorry, file available.";


//SUBMIT BUTTONS
$lang['sub_send'] = 							"send";
$lang['sub_select_all'] = 						"select all";


// OPTIONS
$lang['txt_option_reply'] = 					"reply";
$lang['txt_option_read'] = 						"mark as read";
$lang['txt_option_unread'] = 					"mark as unread";
$lang['txt_option_move'] = 						"move to savebox";
$lang['txt_option_delete'] = 					"delete";
$lang['txt_option_inbox'] = 					"inbox";
$lang['txt_option_outbox'] = 					"outbox";
$lang['txt_option_savebox'] = 					"savebox";
$lang['txt_option_compose'] = 					"compose";


//BODY TEXT
$lang['txt_box'] = 								"box";
$lang['txt_box_in'] = 							"inbox";
$lang['txt_box_out'] = 							"outbox";
$lang['txt_box_save'] = 						"savebox";
$lang['txt_delete_help'] = 						"To delete messages check the box next to the item(s) you want to delete and then press 'delete' button.";
$lang['txt_mess-status_help'] = 				"To mark your messages as read/unread check the box next to the item(s) and then press the 'read'/'unread' button.";
$lang['txt_messages'] = 						"messages";
$lang['txt_move_to_save_help'] = 				"To move messages from you current box to your save box check the box next to the item(s) and then press the 'save' button.";
$lang['txt_opened'] = 							"opened";
$lang['txt_size'] = 							"size";
$lang['txt_totals'] = 							"totals";
$lang['txt_unopened'] = 						"unopened";
$lang['txt_used'] = 							"used";
$lang['txt_mess_status'] = 						"message status";
$lang['txt_mess_delete'] = 						"delete messages";
$lang['txt_mess_save'] = 						"save messages";
$lang['txt_mess_reply'] = 						"reply";

?>
